import numpy as np


def zeroone(m: int, n: int, r, s):
    # Check the inputs are legal or not.
    try:
        assert isinstance(m, int) and isinstance(n, int)
        assert m > 0 and n > 0
        assert r.shape == (m,) and s.shape == (n,)
        assert np.max(r) <= n and np.max(s) <= m
        assert np.sum(r) == np.sum(s)
    except AssertionError:
        print("Illegal inputs!")
    # Initialize a ones matrix which represents all residual capacities on arcs (i.e., r_i->s_j).
    M = np.ones((m, n), dtype=np.int8)
    flow_value = 0
    while True:
        # Find an available path.
        is_a_path_available = False
        for i in range(m):
            for j in range(n):
                if r[i] > 0 and M[i, j] > 0 and s[j] > 0:  # Successfully find a path.
                    r[i] -= 1  # Update residual capacities on arcs source->r_i.
                    M[i, j] -= 1  # Update residual capacities on arcs r_i->s_j.
                    s[j] -= 1  # Update residual capacities on arcs s_j->sink.
                    flow_value += 1  # Increase current flow received by 1.
                    is_a_path_available = True
                    break
        if (not is_a_path_available):  # We cannot find a available path now, should jump out of our while-loop.
            break
    flag = False
    matrix = np.ones((m, n), dtype=np.int8)
    if np.max(r) == 0 and np.max(s) == 0:  # Residual capacities on source->r_i and s_j->sink are all zeros, which means we get the maximal flow.
        flag = True
        print("Yes")
        matrix -= M  # Current flow = Ones matrix(the original capacities on arcs r_i->s_j) - M.
        print(matrix)
    else:
        print("No")
        matrix = None
        print(matrix)
    return flag, matrix


print("Example:")
m, n = 4, 6
r, s = np.array([3, 2, 3, 4]), np.array([3, 2, 2, 3, 1, 1])
flag, matrix = zeroone(m, n, r, s)
print("Dataset 1:")
m, n = 5, 5
r, s = np.array([2, 1, 2, 1, 3]), np.array([2, 1, 3, 1, 2])
flag, matrix = zeroone(m, n, r, s)
print("Dataset 2:")
m, n = 6, 8
r, s = np.array([4, 3, 2, 1, 3, 1]), np.array([2, 1, 3, 1, 2, 4, 2, 2])
flag, matrix = zeroone(m, n, r, s)
print("Dataset 3:")
m, n = 4, 4
r, s = np.array([1, 1, 1, 1]), np.array([1, 1, 1, 1])
flag, matrix = zeroone(m, n, r, s)
print("Dataset 4:")
m, n = 7, 7
r, s = np.array([1, 2, 3, 3, 2, 2, 1]), np.array([2, 5, 1, 1, 1, 1, 1])
flag, matrix = zeroone(m, n, r, s)